---
name: Bug Report
about: Report a bug encountered while operating GramAdict
labels: kind/bug

---
<!-- Please use this template while reporting a bug and provide as much info as possible. Not doing so may result in your bug not being addressed in a timely manner. Thanks! -->


**What happened**:

**What you expected to happen**:

**How to reproduce it (as minimally and precisely as possible)**:

**Anything else we need to know?**:

**Environment**:
- GramAddict version:
- Device Model/Emulator Type:
- Android Version:
- Instagram Version:
- Discord Ticket ID:           *(if submitting crash log)


Relevant Logs:
- activate debug mode in confing.yml if you want to paste from the console, otherwise attach the log file from the logs folder



<br /><br /><br />
### *Note: if you have a crash log, please do not attach the archive here as this is not a secure place to upload the sensitive data inside. Please open a ticket in [Discord](https://discord.com/invite/66zWWCDM7x) in #lobby and provide the ticket ID here.